@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2025  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -152,38 +152,36 @@ void CommandApplyChanges::show_arguments() {
 
 namespace {
 
-    /**
-     *  Copy the first OSM object with a given Id to the output. Keep
-     *  track of the Id of each object to do this.
-     *
-     *  We are using this functor class instead of a simple lambda, because the
-     *  lambda doesn't build on MSVC.
-     */
-    class copy_first_with_id {
+/**
+ *  Copy the first OSM object with a given Id to the output. Keep
+ *  track of the Id of each object to do this.
+ *
+ *  We are using this functor class instead of a simple lambda, because the
+ *  lambda doesn't build on MSVC.
+ */
+class copy_first_with_id {
 
-        osmium::io::Writer* writer;
-        osmium::object_id_type id = 0;
+    osmium::io::Writer* writer;
+    osmium::object_id_type id = 0;
 
-    public:
+public:
 
-        explicit copy_first_with_id(osmium::io::Writer* w) :
-            writer(w) {
-        }
+    explicit copy_first_with_id(osmium::io::Writer* w) :
+        writer(w) {
+    }
 
-        void operator()(const osmium::OSMObject& obj) {
-            if (obj.id() != id) {
-                if (obj.visible()) {
-                    (*writer)(obj);
-                }
-                id = obj.id();
+    void operator()(const osmium::OSMObject& obj) {
+        if (obj.id() != id) {
+            if (obj.visible()) {
+                (*writer)(obj);
             }
+            id = obj.id();
         }
+    }
 
-    }; // class copy_first_with_id
+}; // class copy_first_with_id
 
-} // anonymous namespace
-
-static void update_nodes_if_way(osmium::OSMObject* object, const location_index_type& location_index) {
+void update_nodes_if_way(osmium::OSMObject* object, const location_index_type& location_index) {
     if (object->type() != osmium::item_type::way) {
         return;
     }
@@ -196,6 +194,8 @@ static void update_nodes_if_way(osmium::OSMObject* object, const location_index_
     }
 }
 
+} // anonymous namespace
+
 void CommandApplyChanges::apply_changes_and_write(osmium::ObjectPointerCollection &objects,
                                                   const std::vector<osmium::memory::Buffer> &changes,
                                                   osmium::io::Reader &reader,
@@ -275,6 +275,13 @@ void CommandApplyChanges::apply_changes_and_write(osmium::ObjectPointerCollectio
 }
 
 bool CommandApplyChanges::run() {
+    if (m_locations_on_ways) {
+        m_output_file.set("locations_on_ways");
+    }
+
+    m_vout << "Opening output file...\n";
+    osmium::io::Writer writer{m_output_file, m_output_overwrite, m_fsync};
+
     std::vector<osmium::memory::Buffer> changes;
     osmium::ObjectPointerCollection objects;
 
@@ -302,13 +309,7 @@ bool CommandApplyChanges::run() {
     if (m_with_history) {
         header.set_has_multiple_object_versions(true);
     }
-
-    if (m_locations_on_ways) {
-        m_output_file.set("locations_on_ways");
-    }
-
-    m_vout << "Opening output file...\n";
-    osmium::io::Writer writer{m_output_file, header, m_output_overwrite, m_fsync};
+    writer.set_header(header);
 
     if (m_with_history) {
         // For history files this is a straightforward sort of the change
