@@ -6,7 +6,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2025  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -25,15 +25,23 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 #include "cmd.hpp" // IWYU pragma: export
 
+#include <osmium/osm/crc.hpp>
+#include <osmium/osm/crc_zlib.hpp>
+
 #include <string>
 #include <vector>
 
 class CommandDiff : public CommandWithMultipleOSMInputs, public with_osm_output {
 
     std::string m_output_action;
+    bool m_ignore_attrs_changeset = false;
+    bool m_ignore_attrs_uid = false;
+    bool m_ignore_attrs_user = false;
     bool m_show_summary = false;
     bool m_suppress_common = false;
 
+    void update_object_crc(osmium::CRC<osmium::CRC_zlib>* crc, const osmium::OSMObject &object) const;
+
 public:
 
     explicit CommandDiff(const CommandFactory& command_factory) :
