@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2025  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -36,7 +36,9 @@ bool CommandHelp::setup(const std::vector<std::string>& arguments) {
     return true;
 }
 
-static void show_help(const std::string& topic, const std::string& info) {
+namespace {
+
+void show_help(const std::string& topic, const std::string& info) {
 #ifndef _WIN32
     // show man page on non-Windows systems
     std::string manpage{"osmium-"};
@@ -49,6 +51,8 @@ static void show_help(const std::string& topic, const std::string& info) {
     std::cout << "You'll find more documentation at https://osmcode.org/osmium-tool/\n";
 }
 
+} // anonymous namespace
+
 bool CommandHelp::run() {
     const auto commands = m_command_factory.help();
 
