@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2025  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -35,7 +35,9 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <utility>
 #include <vector>
 
-static void add_ring(std::vector<osmium::Segment>* segments, const osmium::NodeRefList& ring) {
+namespace {
+
+void add_ring(std::vector<osmium::Segment>* segments, const osmium::NodeRefList& ring) {
     const auto* it = ring.begin();
     const auto* const end = ring.end();
 
@@ -50,6 +52,8 @@ static void add_ring(std::vector<osmium::Segment>* segments, const osmium::NodeR
     }
 }
 
+} // anonymous namespace
+
 const osmium::Area& ExtractPolygon::area() const noexcept {
     return m_buffer.get<osmium::Area>(m_offset);
 }
