@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2025  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -30,77 +30,75 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <osmium/memory/buffer.hpp>
 #include <osmium/osm/location.hpp>
 
-#include <rapidjson/document.h>
-#include <rapidjson/error/en.h>
-#include <rapidjson/istreamwrapper.h>
-
 #include <algorithm>
 #include <cassert>
+#include <cstdlib>
 #include <fstream>
 #include <string>
+#include <utility>
 #include <vector>
 
-std::string get_value_as_string(const rapidjson::Value& object, const char* key) {
-    assert(object.IsObject());
+std::string get_value_as_string(const nlohmann::json& object, const char* key) {
+    assert(object.is_object());
 
-    const auto it = object.FindMember(key);
-    if (it == object.MemberEnd()) {
-        return "";
+    const auto it = object.find(key);
+    if (it == object.end()) {
+        return {};
     }
 
-    if (it->value.IsString()) {
-        return it->value.GetString();
+    if (it->is_string()) {
+        return it->template get<std::string>();
     }
 
     throw config_error{std::string{"Value for name '"} + key + "' must be a string."};
 }
 
+namespace {
+
 // parse coordinate pair from JSON array
-osmium::geom::Coordinates parse_coordinate(const rapidjson::Value& value) {
-    if (!value.IsArray()) {
+osmium::geom::Coordinates parse_coordinate(const nlohmann::json& value) {
+    if (!value.is_array()) {
         throw config_error{"Coordinates must be an array."};
     }
 
-    const auto array = value.GetArray();
-    if (array.Size() != 2) {
+    if (value.size() != 2) {
         throw config_error{"Coordinates array must have exactly two elements."};
     }
 
-    if (array[0].IsNumber() && array[1].IsNumber()) {
-        return osmium::geom::Coordinates{array[0].GetDouble(), array[1].GetDouble()};
+    if (value[0].is_number() && value[1].is_number()) {
+        return osmium::geom::Coordinates{value[0].template get<double>(),
+                                         value[1].template get<double>()};
     }
 
     throw config_error{"Coordinates array must contain numbers."};
 }
 
-std::vector<osmium::geom::Coordinates> parse_ring(const rapidjson::Value& value) {
-    if (!value.IsArray()) {
+std::vector<osmium::geom::Coordinates> parse_ring(const nlohmann::json& value) {
+    if (!value.is_array()) {
         throw config_error{"Ring must be an array."};
     }
 
-    const auto array = value.GetArray();
-    if (array.Size() < 3) {
+    if (value.size() < 3) {
         throw config_error{"Ring must contain at least three coordinate pairs."};
     }
 
     std::vector<osmium::geom::Coordinates> coordinates;
 
-    for (const rapidjson::Value& item : array) {
+    for (const nlohmann::json& item : value) {
         coordinates.push_back(parse_coordinate(item));
     }
 
     return coordinates;
 }
 
-void parse_rings(const rapidjson::Value& value, osmium::builder::AreaBuilder* builder) {
-    assert(value.IsArray());
-    const auto array = value.GetArray();
-    if (array.Empty()) {
+void parse_rings(const nlohmann::json& value, osmium::builder::AreaBuilder* builder) {
+    assert(value.is_array());
+    if (value.empty()) {
         throw config_error{"Polygon must contain at least one ring."};
     }
 
     {
-        auto outer_ring = parse_ring(array[0]);
+        auto outer_ring = parse_ring(value[0]);
         if (!is_ccw(outer_ring)) {
             std::reverse(outer_ring.begin(), outer_ring.end());
         }
@@ -118,8 +116,8 @@ void parse_rings(const rapidjson::Value& value, osmium::builder::AreaBuilder* bu
         }
     }
 
-    for (unsigned int i = 1; i < array.Size(); ++i) {
-        auto inner_ring = parse_ring(array[i]);
+    for (unsigned int i = 1; i < value.size(); ++i) {
+        auto inner_ring = parse_ring(value[i]);
         if (is_ccw(inner_ring)) {
             std::reverse(inner_ring.begin(), inner_ring.end());
         }
@@ -138,7 +136,9 @@ void parse_rings(const rapidjson::Value& value, osmium::builder::AreaBuilder* bu
     }
 }
 
-std::size_t parse_polygon_array(const rapidjson::Value& value, osmium::memory::Buffer* buffer) {
+} // anonymous namespace
+
+std::size_t parse_polygon_array(const nlohmann::json& value, osmium::memory::Buffer* buffer) {
     {
         osmium::builder::AreaBuilder builder{*buffer};
         parse_rings(value, &builder);
@@ -147,17 +147,16 @@ std::size_t parse_polygon_array(const rapidjson::Value& value, osmium::memory::B
     return buffer->commit();
 }
 
-std::size_t parse_multipolygon_array(const rapidjson::Value& value, osmium::memory::Buffer* buffer) {
-    assert(value.IsArray());
-    const auto array = value.GetArray();
-    if (array.Empty()) {
+std::size_t parse_multipolygon_array(const nlohmann::json& value, osmium::memory::Buffer* buffer) {
+    assert(value.is_array());
+    if (value.empty()) {
         throw config_error{"Multipolygon must contain at least one polygon array."};
     }
 
     {
         osmium::builder::AreaBuilder builder{*buffer};
-        for (const auto& polygon : array) {
-            if (!polygon.IsArray()) {
+        for (const auto& polygon : value) {
+            if (!polygon.is_array()) {
                 throw config_error{"Polygon must be an array."};
             }
             parse_rings(polygon, &builder);
@@ -180,17 +179,17 @@ GeoJSONFileParser::GeoJSONFileParser(osmium::memory::Buffer& buffer, std::string
     }
 }
 
-std::size_t GeoJSONFileParser::parse_top(const rapidjson::Value& top) {
-    const auto json_geometry = top.FindMember("geometry");
-    if (json_geometry == top.MemberEnd()) {
+std::size_t GeoJSONFileParser::parse_top(const nlohmann::json& top) {
+    const auto json_geometry = top.find("geometry");
+    if (json_geometry == top.end()) {
         error("Missing 'geometry' name.");
     }
 
-    if (!json_geometry->value.IsObject()) {
+    if (!json_geometry->is_object()) {
         error("Expected 'geometry' value to be an object.");
     }
 
-    const std::string geometry_type{get_value_as_string(json_geometry->value, "type")};
+    const std::string geometry_type{get_value_as_string(*json_geometry, "type")};
     if (geometry_type.empty()) {
         error("Missing 'geometry.type'.");
     }
@@ -198,74 +197,70 @@ std::size_t GeoJSONFileParser::parse_top(const rapidjson::Value& top) {
         error("Expected 'geometry.type' value to be 'Polygon' or 'MultiPolygon'.");
     }
 
-    const auto json_coordinates = json_geometry->value.FindMember("coordinates");
-    if (json_coordinates == json_geometry->value.MemberEnd()) {
+    const auto json_coordinates = json_geometry->find("coordinates");
+    if (json_coordinates == json_geometry->end()) {
         error("Missing 'coordinates' name in 'geometry' object.");
     }
 
-    if (!json_coordinates->value.IsArray()) {
+    if (!json_coordinates->is_array()) {
         error("Expected 'geometry.coordinates' value to be an array.");
     }
 
     if (geometry_type == "Polygon") {
-        return parse_polygon_array(json_coordinates->value, &m_buffer);
+        return parse_polygon_array(*json_coordinates, &m_buffer);
     }
 
-    return parse_multipolygon_array(json_coordinates->value, &m_buffer);
+    return parse_multipolygon_array(*json_coordinates, &m_buffer);
 }
 
 std::size_t GeoJSONFileParser::operator()() {
-    rapidjson::IStreamWrapper stream_wrapper{m_file};
+    try {
+        const nlohmann::json doc = nlohmann::json::parse(m_file);
 
-    rapidjson::Document doc;
-    if (doc.ParseStream<rapidjson::kParseCommentsFlag | rapidjson::kParseTrailingCommasFlag>(stream_wrapper).HasParseError()) {
-        error(std::string{"JSON error at offset "} +
-              std::to_string(doc.GetErrorOffset()) +
-              " : " +
-              rapidjson::GetParseError_En(doc.GetParseError()));
-    }
-
-    if (!doc.IsObject()) {
-        error("Top-level value must be an object.");
-    }
-
-    const std::string type{get_value_as_string(doc, "type")};
-    if (type.empty()) {
-        error("Expected 'type' name with the value 'Feature' or 'FeatureCollection'.");
-    }
-
-    if (type == "Feature") {
-        return parse_top(doc);
-    }
-
-    if (type == "FeatureCollection") {
-        const auto json_features = doc.FindMember("features");
-        if (json_features == doc.MemberEnd()) {
-            error("Missing 'features' name.");
+        if (!doc.is_object()) {
+            error("Top-level value must be an object.");
         }
 
-        if (!json_features->value.IsArray()) {
-            error("Expected 'features' value to be an array.");
+        const std::string type{get_value_as_string(doc, "type")};
+        if (type.empty()) {
+            error("Expected 'type' name with the value 'Feature' or 'FeatureCollection'.");
         }
 
-        const auto json_features_array = json_features->value.GetArray();
-        if (json_features_array.Empty()) {
-            throw config_error{"Features array must contain at least one polygon."};
+        if (type == "Feature") {
+            return parse_top(doc);
         }
 
-        const auto& json_first_feature = json_features_array[0];
-        if (!json_first_feature.IsObject()) {
-            error("Expected values of 'features' array to be a objects.");
+        if (type == "FeatureCollection") {
+            const auto json_features = doc.find("features");
+            if (json_features == doc.end()) {
+                error("Missing 'features' name.");
+            }
+
+            if (!json_features->is_array()) {
+                error("Expected 'features' value to be an array.");
+            }
+
+            if (json_features->empty()) {
+                throw config_error{"Features array must contain at least one polygon."};
+            }
+
+            const auto& json_first_feature = (*json_features)[0];
+            if (!json_first_feature.is_object()) {
+                error("Expected values of 'features' array to be a objects.");
+            }
+
+            const std::string feature_type{get_value_as_string(json_first_feature, "type")};
+
+            if (feature_type != "Feature") {
+                error("Expected 'type' value to be 'Feature'.");
+            }
+
+            return parse_top(json_first_feature);
         }
 
-        const std::string feature_type{get_value_as_string(json_first_feature, "type")};
-
-        if (feature_type != "Feature") {
-            error("Expected 'type' value to be 'Feature'.");
-        }
-
-        return parse_top(json_first_feature);
+        error("Expected 'type' value to be 'Feature'.");
+    } catch (const nlohmann::json::parse_error &e) {
+        error(std::string{"JSON error at offset "} + std::to_string(e.byte) +
+              " : " + e.what());
     }
-
-    error("Expected 'type' value to be 'Feature'.");
 }
