@@ -6,7 +6,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2025  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -25,14 +25,14 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 #include <osmium/memory/buffer.hpp>
 
-#include <rapidjson/document.h>
+#include <nlohmann/json.hpp>
 
 #include <fstream>
 #include <string>
 
-std::string get_value_as_string(const rapidjson::Value& object, const char* key);
-std::size_t parse_polygon_array(const rapidjson::Value& value, osmium::memory::Buffer* buffer);
-std::size_t parse_multipolygon_array(const rapidjson::Value& value, osmium::memory::Buffer* buffer);
+std::string get_value_as_string(const nlohmann::json& object, const char* key);
+std::size_t parse_polygon_array(const nlohmann::json& value, osmium::memory::Buffer* buffer);
+std::size_t parse_multipolygon_array(const nlohmann::json& value, osmium::memory::Buffer* buffer);
 
 /**
  * Gets areas from OSM files.
@@ -45,7 +45,7 @@ class GeoJSONFileParser {
 
     [[noreturn]] void error(const std::string& message);
 
-    std::size_t parse_top(const rapidjson::Value& top);
+    std::size_t parse_top(const nlohmann::json& top);
 
 public:
 
